@@ -91,6 +91,7 @@ void KWalletManagerWidget::updateWalletDisplay(QString selectWallet /* = QString
     if (!selectWallet.isEmpty()) {
         setCurrentPage(_walletPages[selectWallet]);
     }
+    setVisible(!KWallet::Wallet::walletList().isEmpty());
     alreadyUpdating = false;
 }
 
@@ -117,9 +118,13 @@ bool KWalletManagerWidget::openWallet(const QString& name)
     return result;
 }
 
-const QString& KWalletManagerWidget::activeWalletName() const
+const QString KWalletManagerWidget::activeWalletName() const
 {
-    return qobject_cast<KWalletManagerWidgetItem*>(currentPage())->walletName();
+    if (currentPage()) {
+            return qobject_cast<KWalletManagerWidgetItem*>(currentPage())->walletName();
+    } else {
+            return QString();
+    }
 }
 
 void KWalletManagerWidget::dragEnterEvent(QDragEnterEvent* e)
